==> version-handle-0.1.0.tar.gz: version-handle-0.1.0/README.md <==
📦 version-handle
=======================

Time NLP module

Installation
-----

```bash
pip install -i https://mirrors.aliyun.com/pypi/simple/ --extra-index-url https://pypi.org/simple/ version-handle
```

Example
-----

```python
from version_handle import compare, python, generate
compare("11.1-2_3", "9.1-2_3").is_more
# output: True
compare("11.1-2_3", "9.1").is_less
# output: False
compare("11.1-2_3+0006", "11.1-2_3+6").is_equal
# output: True
python.version()
# output: 3.10.5 (v3.10.5:f377153967, Jun  6 2022, 12:36:10) [Clang 13.0.0 (clang-1300.0.29.30)]
generate((0, 11, 12))
# output: 0.11.12
```

To Do
-----

-   Be the best version of you.


More Resources
--------------

-   [version-handle] on github.com
-   [Official Python Packaging User Guide](https://packaging.python.org)
-   [The Hitchhiker's Guide to Packaging]
-   [Cookiecutter template for a Python package]

License
-------

This is free and unencumbered software released into the public domain.

Anyone is free to copy, modify, publish, use, compile, sell, or
distribute this software, either in source code form or as a compiled
binary, for any purpose, commercial or non-commercial, and by any means.

  [version-handle]: https://github.com/holbos-deng/version-handle
  [PyPi]: https://docs.python.org/3/distutils/packageindex.html
  [Twine]: https://pypi.python.org/pypi/twine
  [image]: https://farm1.staticflickr.com/628/33173824932_58add34581_k_d.jpg
  [What is setup.py?]: https://stackoverflow.com/questions/1471994/what-is-setup-py
  [The Hitchhiker's Guide to Packaging]: https://the-hitchhikers-guide-to-packaging.readthedocs.io/en/latest/creation.html
  [Cookiecutter template for a Python package]: https://github.com/audreyr/cookiecutter-pypackage

==> version-handle-0.1.1.tar.gz: version-handle-0.1.1/README.md <==
📦 version-handle
=======================

Version handle module

Installation
-----

```bash
pip install -i https://mirrors.aliyun.com/pypi/simple/ --extra-index-url https://pypi.org/simple/ version-handle
```

Example
-----

```python
from version_handle import compare, python, generate, Version


Version("11.2-3_4") > Version("9.2-3_4a") == Version("9.2-3.4a")
# output: True
compare("11.1-2_3", "9.1-2_3").is_gt
# output: True
compare("11.1-2_3", "9.1-2_3").is_ge
# output: True
compare("11.1-2_3", "9.1").is_lt
# output: False
compare("11.1-2_3a", "9.1b").is_le
# output: False
compare("11.1-2_3+0006", "11.1-2_3+6").is_equal
# output: True
python.version()
# output: 3.10.5 (v3.10.5:f377153967, Jun  6 2022, 12:36:10) [Clang 13.0.0 (clang-1300.0.29.30)]
generate((0, 11, 12))
# output: 0.11.12
```

To Do
-----

-   Be the best version of you.


More Resources
--------------

-   [version-handle] on github.com
-   [Official Python Packaging User Guide](https://packaging.python.org)
-   [The Hitchhiker's Guide to Packaging]
-   [Cookiecutter template for a Python package]

License
-------

This is free and unencumbered software released into the public domain.

Anyone is free to copy, modify, publish, use, compile, sell, or
distribute this software, either in source code form or as a compiled
binary, for any purpose, commercial or non-commercial, and by any means.

  [version-handle]: https://github.com/holbos-deng/version-handle
  [PyPi]: https://docs.python.org/3/distutils/packageindex.html
  [Twine]: https://pypi.python.org/pypi/twine
  [image]: https://farm1.staticflickr.com/628/33173824932_58add34581_k_d.jpg
  [What is setup.py?]: https://stackoverflow.com/questions/1471994/what-is-setup-py
  [The Hitchhiker's Guide to Packaging]: https://the-hitchhikers-guide-to-packaging.readthedocs.io/en/latest/creation.html
  [Cookiecutter template for a Python package]: https://github.com/audreyr/cookiecutter-pypackage
